@@ -10,6 +10,7 @@ mod poll;
 mod queue;
 mod strings;
 mod ui;
+mod version;
 
 use crate::{app::App, poll::QueueEvent};
 use asyncgit::AsyncNotification;
@@ -33,7 +34,10 @@ use std::{
     io, panic,
     time::{Duration, Instant},
 };
-use tui::{backend::CrosstermBackend, Terminal};
+use tui::{
+    backend::{Backend, CrosstermBackend},
+    Terminal,
+};
 
 static TICK_INTERVAL: Duration = Duration::from_secs(5);
 
@@ -65,6 +69,7 @@ fn main() -> Result<()> {
     let ticker = tick(TICK_INTERVAL);
 
     app.update();
+    draw(&mut terminal, &mut app)?;
 
     loop {
         let events: Vec<QueueEvent> =
@@ -81,7 +86,7 @@ fn main() -> Result<()> {
                 }
             }
 
-            terminal.draw(|mut f| app.draw(&mut f))?;
+            draw(&mut terminal, &mut app)?;
 
             if app.is_quit() {
                 break;
@@ -92,6 +97,13 @@ fn main() -> Result<()> {
     Ok(())
 }
 
+fn draw<B: Backend>(
+    terminal: &mut Terminal<B>,
+    app: &mut App,
+) -> io::Result<()> {
+    terminal.draw(|mut f| app.draw(&mut f))
+}
+
 fn invalid_path() -> bool {
     !asyncgit::is_repo(asyncgit::CWD)
 }
