@@ -7,6 +7,7 @@ pub static TAB_DIVIDER: &str = "  |  ";
 
 pub static CMD_SPLITTER: &str = " ";
 
+pub static MSG_TITLE: &str = "Info";
 pub static COMMIT_TITLE: &str = "Commit";
 pub static COMMIT_MSG: &str = "type commit message..";
 pub static RESET_TITLE: &str = "Reset";
@@ -18,6 +19,7 @@ pub mod commands {
     use crate::components::CommandText;
 
     static CMD_GROUP_GENERAL: &str = "General";
+    static CMD_GROUP_DIFF: &str = "Diff";
     static CMD_GROUP_CHANGES: &str = "Changes";
     static CMD_GROUP_COMMIT: &str = "Commit";
 
@@ -34,12 +36,31 @@ pub mod commands {
         CMD_GROUP_GENERAL,
     );
     ///
+    pub static DIFF_HUNK_ADD: CommandText = CommandText::new(
+        "Add hunk [enter]",
+        "adds selected hunk to stage",
+        CMD_GROUP_DIFF,
+    );
+    ///
+    pub static DIFF_HUNK_REMOVE: CommandText = CommandText::new(
+        "Remove hunk [enter]",
+        "removes selected hunk from stage",
+        CMD_GROUP_DIFF,
+    );
+    ///
     pub static CLOSE_POPUP: CommandText = CommandText::new(
         "Close [esc]",
         "close overlay (e.g commit, help)",
         CMD_GROUP_GENERAL,
     );
     ///
+    pub static CLOSE_MSG: CommandText = CommandText::new(
+        "Close [enter]",
+        "close msg popup (e.g msg)",
+        CMD_GROUP_GENERAL,
+    )
+    .hide_help();
+    ///
     pub static COMMIT_OPEN: CommandText = CommandText::new(
         "Commit [c]",
         "open commit view (available in non-empty stage)",
